@@ -13,9 +13,6 @@ from io import StringIO
 from math import floor
 from alacorder import run
 from alacorder import alac
-import warnings
-
-warnings.filterwarnings("ignore")
 
 print('''
 
@@ -26,7 +23,7 @@ print('''
 	/_/  |_/_/\\__,_/\\___/\\____/_/   \\__,_/\\___/_/     
 																																														
 		
-		ALACORDER beta 0.5.7
+		ALACORDER beta 0.5.63
 		by Sam Robson	
 
 
@@ -55,8 +52,7 @@ B.	CREATE A FULL TEXT ARCHIVE FROM PDF CASES
 	Outputs:	Archive (.pkl, .csv, .xls, .json) or
 			non-importable text file (.txt)
 
->> Enter A or B:
-''')
+>> Enter A or B: ''')
 
 ab = "".join(input()).strip()
 
@@ -67,16 +63,14 @@ if ab == "A":
 			ex.	/full/path/to/pdf/folder/
 			ex.	/full/path/to/fulltextarchive.pkl
 
-	>> Input path:
-''')
+	>> Input path: ''')
 elif ab == "B":
 	print(f'''
 
 	>>	Enter the input PDF directory path, including a forward-slash.
 			ex.	/full/path/to/pdf/folder/
 
-	>> Input path: 
-''')
+	>> Input path: ''')
 else:
 	raise Exception("Not a valid input!")
 
@@ -93,8 +87,7 @@ if ab == "A":
 			ex.	/full/path/to/casestable.xls
 			ex.	/full/path/to/cases.csv
 
-	>> Output path: 
-''')
+	>> Output path: ''')
 elif ab == "B":
 	print(f'''
 
@@ -102,8 +95,7 @@ elif ab == "B":
 			ex.	/full/path/to/fulltextarchive.pkl
 			ex.	/path/to/archive.csv
 
-	>> Output path: 
-''')
+	>> Output path: ''')
 else:
 	raise Exception("Not a valid input!")
 
@@ -137,8 +129,7 @@ if mode == "archive-from-directory":
 		information table from the 
 		full text archive data?
 
-Enter Y/N:	
-''')
+Enter Y/N:	''')
 	info = "".join(input()).strip()
 	if info == "Y":
 		print(f'''
@@ -146,11 +137,10 @@ Enter Y/N:
 			ex.	/full/path/to/fulltextarchive.pkl
 			ex.	/path/to/archive.csv 
 
-Output Path: 
-''')
+Output Path: ''')
 		in_dir = xpath
 		xpath = "".join(input()).strip()
-		run.start(in_dir,xpath,"tables-from-archive",batch_size=2500)
+		run.start(in_dir,xpath,"tables-from-archive",batch_size=2000)
 	if info == "N":
 		print(f'''
 			Alacorder completed the task and will now quit.
