@@ -12,13 +12,13 @@ from math import floor
 import datetime
 import pandas as pd
 import numpy as np
-import PyPDF2 as pypdf
+import PyPDF2 as pdfs
 
 
 
 def getPDFText(path: str) -> str:
 	text = ""
-	pdf = pypdf.PdfReader(path)
+	pdf = pdfs.PdfReader(path)
 	for pg in pdf.pages:
 		text += pg.extract_text() + "\n"
 	return str(text)
@@ -39,22 +39,18 @@ def getCaseInfo(text: str):
 	except (IndexError, AttributeError):
 		pass
  
+	#try:
 	if bool(re.search(r'(?a)(VS\.|V\.{1})(.+)(Case)*', text, re.MULTILINE)) == True:
 		name = re.search(r'(?a)(VS\.|V\.{1})(.+)(Case)*', text, re.MULTILINE).group(2).replace("Case Number:","").strip()
 	else:
 		if bool(re.search(r'(?:DOB)(.+)(?:Name)', text, re.MULTILINE)) == True:
 			name = re.search(r'(?:DOB)(.+)(?:Name)', text, re.MULTILINE).group(1).replace(":","").replace("Case Number:","").strip()
-	if bool(re.search(r'(SSN).{5,75}?(Alias)',text, re.MULTILINE)) == True:
-		alias = re.search(r'(SSN)(.{5,75})(Alias)?', text, re.MULTILINE).group(2).replace(":","").replace("Alias 1","").strip()
-	else:
-		pass
+	
+	alias = "" # Add support for PyPDF2 version, in meantime crawl with PDFPlumber version
+
 	try:
 		dob: str = re.search(r'(\d{2}/\d{2}/\d{4})(?:.{0,5}DOB\:)', str(text), re.DOTALL).group(1)
 		phone: str = re.search(r'(?:Phone\:)(.*?)(?:Country)', str(text), re.DOTALL).group(1).strip()
-		if len(phone) < 7:
-			phone = ""
-		if len(phone) > 10 and phone[-3:] == "000":
-			phone = phone[0:9]
 	except (IndexError, AttributeError):
 		dob = ""
 		phone = ""
@@ -65,24 +61,13 @@ def getCaseInfo(text: str):
 	except (IndexError, AttributeError):
 		pass
 	try:
-		street_addr = re.search(r'(Address 1\:)(.+)', str(text), re.MULTILINE).group(2).strip()
-	except (IndexError, AttributeError):
-		street_addr = ""
-	try:
-		zip_code = re.search(r'(Zip\: )(.+)', str(text), re.MULTILINE).group(2).strip()	
-	except (IndexError, AttributeError):
-		zip_code = ""
-	try:
-		city = re.search(r'(City\: )(.*)(State\: )(.*)', str(text), re.MULTILINE).group(2).strip()
-	except (IndexError, AttributeError):
-		city = ""
-	try:
-		state = re.search(r'(?:City\: ).*(?:State\: ).*', str(text), re.MULTILINE).group(4).strip()
-	except (IndexError, AttributeError):
-		state = ""
-	
-	address = street_addr + " " + city + ", " + state + " " + zip_code
-
+		street_addr = re.search(r'(?:Address 1\:)(.+)', str(text), re.MULTILINE).group(1).strip()
+		zip_code = re.search(r'(?:Zip\: ).+', str(text), re.MULTILINE).group().strip()
+		city = re.search(r'(?:City\: ).*(?:State\: ).*', str(text), re.MULTILINE).group(1).strip()
+		state = re.search(r'(?:City\: ).*(?:State\: ).*', str(text), re.MULTILINE).group(2).strip()
+		address = street_addr + "	" + city + ", " + state + " " + zip_code
+	except(IndexError, AttributeError):
+		pass
 	case = [
 		case_num,
 		name,
@@ -96,10 +81,10 @@ def getCaseInfo(text: str):
 
 	return case
 
-def getFeeSheet(text: str, cnum: str):
+def getFeeSheet(text: str):
 	actives = re.findall(r'(ACTIVE.*\$.*)', str(text))
 	rind = range(0, len(actives))
-	fees = pd.DataFrame({'Rows':actives,'CaseNumber':cnum},index=rind)
+	fees = pd.DataFrame({'Rows':actives},index=rind)
 	try:
 		totalrow = re.findall(r'(Total.*\$.*)', str(text), re.MULTILINE)[0]
 		tbal = totalrow.split("$")[1].strip().replace("Total: $","").replace(",","").replace(" ","")
@@ -116,8 +101,7 @@ def getFeeSheet(text: str, cnum: str):
 	fees['AmtPaid'] = fees['DRows'].map(lambda x: x[2] if len(x)>2 else "")
 	fees['Balance'] = fees['DRows'].map(lambda x: x[1] if len(x)>3 else "")
 	fees['AmtHold'] = fees['DRows'].map(lambda x: x[3] if len(x)>4 else "")
-	fees['CaseNumber'] = fees.index.map(lambda x: cnum)
-
+	
 	try:
 		d999 = fees['Balance'][fees.Code == "D999"]
 	except (TypeError, IndexError):
@@ -125,29 +109,20 @@ def getFeeSheet(text: str, cnum: str):
 
 	owe_codes = " ".join(fees['Code'][fees.Balance.str.len() > 1])
 	codes = " ".join(fees['Code'])
-	allrows = actives
+	allrows = []
+	allrows.append(actives)
 	allrows.append(totalrow)
-	allrowstr = "\n".join(allrows)
-	return [tdue, tbal, d999, owe_codes, codes, allrowstr, fees]
+	return [tdue, tbal, d999, owe_codes, codes, allrows]
 
-def getCharges(text: str, cnum: str):
+def getCharges(text: str):
 	# get all charges matches
-	ch = re.findall(r'(\d{3}\s{1}.{1,100}?.{3}-.{3}-.{3}.{10,75})', str(text), re.MULTILINE)
-	c = []
-	for a in ch:
-		b = str(a).replace("Sentences","").replace("Sentence 1","").replace("SentencesSentence 1","").replace("Sentence","").replace("Financial","")
-		if b[-2:] == " 1" or b[-2:] == " 0":
-			b = b.replace(" 1","").replace(" 0","").strip()
-		if ":" in b:
-			continue
-		c.append(re.sub(r'[a-z]*','', b))
+	c = re.findall(r'(\d{3}\s{1}.{1,100}?.{3}-.{3}-.{3}.*)', str(text), re.MULTILINE)
 	cind = range(0, len(c))
 	charges = pd.DataFrame({'Charges': c},index=cind)
-	charges['CaseNumber'] = charges.index.map(lambda x: cnum)
 	# find table fields
 	split_charges = charges['Charges'].map(lambda x: x.split(" "))
 	charges['Num'] = split_charges.map(lambda x: x[0].strip())
-	charges['Code'] = split_charges.map(lambda x: x[1].strip()[0:4])
+	charges['Code'] = split_charges.map(lambda x: x[1].strip())
 	charges['Felony'] = charges['Charges'].map(lambda x: bool(re.search(r'FELONY',x)))
 	charges['Conviction'] = charges['Charges'].map(lambda x: bool(re.search(r'GUILTY|CONVICTED',x)))
 	charges['VRRexception'] = charges['Charges'].map(lambda x: bool(re.search(r'(A ATT|ATTEMPT|S SOLICIT|CONSP)',x)))
@@ -160,7 +135,7 @@ def getCharges(text: str, cnum: str):
 	charges['Disposition'] = charges['Charges'].map(lambda x: bool(re.search(r'\d{2}/\d{2}/\d{4}', x)))
 	charges['CourtActionDate'] = charges['Charges'].map(lambda x: re.search(r'\d{2}/\d{2}/\d{4}', x).group() if bool(re.search(r'\d{2}/\d{2}/\d{4}', x)) else "")
 	charges['CourtAction'] = charges['Charges'].map(lambda x: re.search(r'(BOUND|GUILTY PLEA|PROBATION|WAIVED|DISMISSED|TIME LAPSED|NOL PROSS|CONVICTED|INDICTED|OTHER|DISMISSED|FORFEITURE|TRANSFER|REMANDED|PROBATION|ACQUITTED|WITHDRAWN|PETITION|PRETRIAL|COND\. FORF\.)', x).group() if bool(re.search(r'(BOUND|GUILTY PLEA|PROBATION|WAIVED|DISMISSED|TIME LAPSED|NOL PROSS|CONVICTED|INDICTED|OTHER|DISMISSED|FORFEITURE|TRANSFER|REMANDED|PROBATION|ACQUITTED|WITHDRAWN|PETITION|PRETRIAL|COND\. FORF\.)', x)) else "")
-	charges['Cite'] = charges['Charges'].map(lambda x: re.search(r'([^\s]{3}-[^\s]{3}-[^\s]{3}[^s]{0,3}?\)*)', x).group() if bool(re.search(r'([^\s]{3}-[^\s]{3}-[^\s]{3}[^s]{0,3}?\)*)', x)) else re.search(r'(.{3}-.{3}-)',x).group() if bool(re.search(r'(.{3}-.{3}-)',x)) else "")
+	charges['Cite'] = charges['Charges'].map(lambda x: re.search(r'([^\s]{3}-[^\s]{3}-[^\s]{3}[^s]{0,3}?\)*)', x).group() if bool(re.search(r'([^\s]{3}-[^\s]{3}-[^\s]{3}[^s]{0,3}?\)*)', x)) else re.search(r'(.{3}-.{3}-)',x).group())
 	charges['TypeDescription'] = charges['Charges'].map(lambda x: re.search(r'(BOND|FELONY|MISDEMEANOR|OTHER|TRAFFIC|VIOLATION)', x).group() if bool(re.search(r'(BOND|FELONY|MISDEMEANOR|OTHER|TRAFFIC|VIOLATION)', x)) else "")
 	charges['Category'] = charges['Charges'].map(lambda x: re.search(r'(ALCOHOL|BOND|CONSERVATION|DOCKET|DRUG|GOVERNMENT|HEALTH|MUNICIPAL|OTHER|PERSONAL|PROPERTY|SEX|TRAFFIC)', x).group() if bool(re.search(r'(ALCOHOL|BOND|CONSERVATION|DOCKET|DRUG|GOVERNMENT|HEALTH|MUNICIPAL|OTHER|PERSONAL|PROPERTY|SEX|TRAFFIC)', x)) else "")
 	charges['Description'] = charges.index.map(lambda x: charges['Charges'][x].replace(charges['Code'][x],"").replace(charges['Cite'][x],"").replace(charges['Category'][x],"").replace(charges['TypeDescription'][x],"").replace(charges['Num'][x],"").replace(charges['CourtAction'][x],"").replace(charges['CourtActionDate'][x],"").replace("Sentences","").replace("Sentence 1","").strip())
@@ -178,13 +153,14 @@ def getCharges(text: str, cnum: str):
 
 	# summary strings
 	convictions = "; ".join(charges[charges.Conviction == True]['Charges'].tolist())
-	conv_codes = " ".join(charges[charges.Conviction == True]['Code'].tolist())
-	charge_codes = " ".join(charges[charges.Disposition == True]['Code'].tolist())
 	dcharges = "; ".join(charges[charges.Disposition == True]['Charges'].tolist())
 	fcharges = "; ".join(charges[charges.Disposition == False]['Charges'].tolist())
 	cerv_convictions = "; ".join(charges[charges.CERV == True][charges.Conviction == True]['Charges'].tolist())
 	pardon_convictions = "; ".join(charges[charges.Pardon == True][charges.Conviction == True]['Charges'].tolist())
 	perm_convictions = "; ".join(charges[charges.Permanent == True][charges.Conviction == True]['Charges'].tolist())
 
-	return [convictions, dcharges, fcharges, cerv_convictions, pardon_convictions, perm_convictions, conviction_ct, charge_ct, cerv_ct, pardon_ct, perm_ct, conv_cerv_ct, conv_pardon_ct, conv_perm_ct, charge_codes, conv_codes, "; ".join(charges['Charges'])]
+	return [convictions, dcharges, fcharges, cerv_convictions, pardon_convictions, perm_convictions, conviction_ct, charge_ct, cerv_ct, pardon_ct, perm_ct, conv_cerv_ct, conv_pardon_ct, conv_perm_ct]
+
+
+
 
